@@ -1,26 +1,29 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 """Base Agent class used in FL."""
 
 from abc import ABCMeta, abstractmethod
-from torch.utils.data import DataLoader
-from torchfl.federated.fl_params import FLParams
-from typing import Optional, Any
+from typing import Any
 
 import pytorch_lightning as pl
+from torch.utils.data import DataLoader
+
+from torchfl.federated.fl_params import FLParams
 
 
 class BaseAgent(metaclass=ABCMeta):
     """BaseAgent class used in FL."""
 
     def __init__(
-        self, id: int, data_shard: DataLoader, model: Optional[Any] = None
+        self,
+        id: int,
+        data_shard: DataLoader,
+        model: Any,
     ) -> None:
         """Constructor."""
         self.id: int = id
         self.data_shard: DataLoader = data_shard
-        self.model: Optional[Any] = model
+        self.model: Any = model
 
     def assign_model(self, model: Any) -> None:
         """Assign a model to the agent."""
