@@ -1,11 +1,11 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 """Random Sampler class used in FL."""
 
 import random
+from typing import Any
+
 from torchfl.federated.samplers.base import BaseSampler
-from typing import Any, List
 
 random.seed(42)
 
@@ -13,11 +13,11 @@ random.seed(42)
 class RandomSampler(BaseSampler):
     """RandomSampler class used in FL."""
 
-    def __init__(self, all_agents: List[Any]) -> None:
+    def __init__(self, all_agents: list[Any]) -> None:
         """Constructor."""
         super().__init__(all_agents=all_agents)
 
-    def sample(self, num: int) -> List[Any]:
+    def sample(self, num: int) -> list[Any]:
         """
         Sample agents.
 
