@@ -1,13 +1,14 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # type: ignore
 
 """Implementation of the general LeNet architecture using PyTorch."""
 
-import torch.nn as nn
-from torchfl.models.sota.mlp import LinearBlock
 from types import SimpleNamespace
+
+import torch.nn as nn
+
 from torchfl.compatibility import ACTIVATION_FUNCTIONS_BY_NAME
+from torchfl.models.sota.mlp import LinearBlock
 
 
 class LeNet(nn.Module):
@@ -23,7 +24,7 @@ class LeNet(nn.Module):
             - num_channels (int, optional): Number of channels for the images in the dataset. Defaults to 3.
             - act_fn_name (str, optional): Activation function to be used. Defaults to "relu". Accepted: ["tanh", "relu", "leakyrelu", "gelu"].
         """
-        super(LeNet, self).__init__()
+        super().__init__()
         self.hparams = SimpleNamespace(
             model_name="lenet",
             num_classes=num_classes,
@@ -39,7 +40,13 @@ class LeNet(nn.Module):
 
     def _create_network(self):
         self.input_net = nn.Sequential(
-            nn.Conv2d(self.hparams.num_channels, 6, kernel_size=5, stride=1, padding=2),
+            nn.Conv2d(
+                self.hparams.num_channels,
+                6,
+                kernel_size=5,
+                stride=1,
+                padding=2,
+            ),
             self.hparams.act_fn(),
             nn.AvgPool2d(kernel_size=2, stride=2),
         )
@@ -49,9 +56,11 @@ class LeNet(nn.Module):
             nn.Conv2d(16, 120, kernel_size=5, stride=1),
             self.hparams.act_fn(),
             nn.Flatten(start_dim=1),
-            LinearBlock(120, 84, self.hparams.act_fn, False),
+            LinearBlock(300000, 84, self.hparams.act_fn, False),
+        )
+        self.output_net = nn.Sequential(
+            nn.Linear(84, self.hparams.num_classes)
         )
-        self.output_net = nn.Sequential(nn.Linear(84, self.hparams.num_classes))
 
     def forward(self, x):
         """Forward propagation
